djmessenger.management.commands package
=======================================

Submodules
----------

djmessenger.management.commands.configure_get_started_button module
-------------------------------------------------------------------

.. automodule:: djmessenger.management.commands.configure_get_started_button
    :members:
    :undoc-members:
    :show-inheritance:

djmessenger.management.commands.configure_greetings module
----------------------------------------------------------

.. automodule:: djmessenger.management.commands.configure_greetings
    :members:
    :undoc-members:
    :show-inheritance:

djmessenger.management.commands.configure_persistent_menu module
----------------------------------------------------------------

.. automodule:: djmessenger.management.commands.configure_persistent_menu
    :members:
    :undoc-members:
    :show-inheritance:

djmessenger.management.commands.get_random_endpoint module
----------------------------------------------------------

.. automodule:: djmessenger.management.commands.get_random_endpoint
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: djmessenger.management.commands
    :members:
    :undoc-members:
    :show-inheritance:
